@@ -2,26 +2,45 @@
 The central delegation of the CPPython project
 """
 
+from dataclasses import dataclass
 from importlib import metadata
 from typing import Callable, Optional, Type, TypeVar
+from xmlrpc.client import Boolean
 
 from cppython_core.exceptions import ConfigError
 from cppython_core.schema import API, Generator, Interface, Plugin, PyProject
 
 
+@dataclass
+class ProjectConfiguration:
+    """
+    TODO
+    """
+
+    verbose: Boolean = False
+
+
 class Project(API):
     """
     The object constructed at each entry_point
     """
 
-    def __init__(self, interface: Interface, pyproject: PyProject) -> None:
+    def __init__(self, configuration: ProjectConfiguration, interface: Interface, pyproject: PyProject) -> None:
 
         self.enabled = False
+        self.verbose = configuration.verbose
+
+        if self.verbose:
+            interface.print("Starting CPPython project initialization")
 
         if pyproject.tool is None:
+            if self.verbose:
+                interface.print("Table [tool] is not defined")
             return
 
         if pyproject.tool.cppython is None:
+            if self.verbose:
+                interface.print("Table [tool.cppython] is not defined")
             return
 
         self.enabled = True
@@ -53,6 +72,9 @@ class Project(API):
         generator_data = interface.read_generator_data(plugin_type.data_type())
         self._generator = plugin_type(pyproject, generator_data)
 
+        if self.verbose:
+            interface.print("CPPython project initialized")
+
     def download(self):
         """
         Download the generator tooling if required
@@ -68,13 +90,19 @@ class Project(API):
 
     def install(self) -> None:
         if self.enabled:
+            if self.verbose:
+                self._interface.print("CPPython: Installing...")
             self.download()
             self._generator.install()
 
     def update(self) -> None:
         if self.enabled:
+            if self.verbose:
+                self._interface.print("CPPython: Updating...")
             self._generator.update()
 
     def build(self) -> None:
         if self.enabled:
+            if self.verbose:
+                self._interface.print("CPPython: Building...")
             self._generator.build()
